#!/bin/csh
#
# cardupload.csh - Copies camera CF card to dropped directory. Creates dir if clicked.

#set echo

onintr exit

set prog_name = "cardupload.csh";
set version = "v1.0";
set credit = "Mark Harris May 2007"
set prog = `echo $prog_name | sed -e s/"\.[^\.]*"//`

set ccd = "$1/Contents/Resources/CocoaDialog.app/Contents/MacOS/CocoaDialog"
set dirs_sidecar = "$1/Contents/Resources/cardupload_dirs.txt"

# Check for device file

if (! -e "$dirs_sidecar") then
    if ($#argv != 2 || `echo "$2" | grep "Volumes"` == "") then
		set ret = `"$ccd" msgbox --title "$prog" --float --text "Setup required" --informative-text "CardUpload needs to know what folder to copy from.         Go to the device from which you want to copy files, drag the folder containing the files on to CardUpload, and you will be prompted what to do. You only need to do this once, when you start using a device with a new name." --button1 "OK" --button2 "Help"`
  		set retcode = `echo $ret | cut -c1`
  		if ("$retcode" == "2") then
    		set ret = `"$ccd" msgbox --title "$prog" --float --text "Help" --informative-text "CardUpload copies files from a removable device to a folder, for example images from a digital camera. You must first set the default device source folder by dropping that folder on to the application. After that, dropping a folder on the application will cause files to be copied from that device folder to the dropped folder. Starting the application with no folder will prompt to create a new folder." --button1 "OK"`
    	exit
  		endif # end help
	endif # end not /Volumes
else
	# Get card device name, and root for new dirs from sidecar file
	set card_name = `cat $dirs_sidecar | sed -n '1,1 p'`
	set dir_root = `cat $dirs_sidecar | sed -n '2,2 p'`
	set date_flag = `cat $dirs_sidecar | sed -n '3,3 p'`
endif
	
if ($#argv == 2) then # Folder dropped

  set dir_name = "$2"

  if (`echo "$dir_name" | grep "Volumes"` != "") then # Device dropped, assume card reader
	if (! -d "$dir_name") then # They dropped a file, get parent dir
	 	set card_name = `echo "$dir_name" | sed -e s/'\/[^/]*$'//`
	else
	  set card_name = "$dir_name"
	  set found_file = `find "$dir_name" -name "*.jpg" -print | grep -v Trash | head -1`
	  if ("$found_file" == "") set found_file = `find "$dir_name" -name "*.JPG" -print | grep -v Trash | head -1`
	  if ("$found_file" == "") set found_file = `find "$dir_name" -name "*.NEF" -print | grep -v Trash | head -1`
	  if ("$found_file" == "") set found_file = `find "$dir_name" -name "*.RAW" -print | grep -v Trash | head -1`
	  if ("$found_file" != "") set card_name = `echo "$found_file" | sed -e s/'\/[^/]*$'//`		
	endif
	set dir_name = `echo "$1" | sed -e s/'\/[^/]*$'//` # Set folder root to cwd for app

  	set ret = `"$ccd" inputbox --title "$prog" --informative-text "Default location for creating new folders :" --button1 "Append year and month" --button2 "Use this folder" --button3 "Cancel" --float --text "$dir_name"`

  	set retcode = `echo $ret | cut -c1`
    if ("$retcode" == "3") exit
 	set dir_name = `echo $ret | cut -c2-`

	echo "$card_name" > $dirs_sidecar
	echo "$dir_name" >> $dirs_sidecar

    if ("$retcode" == "1") echo "DATE" >> $dirs_sidecar

    set ret = `"$ccd" msgbox --title "$prog" --float --text "New defaults set" --informative-text "Card device set to : $card_name           Folder root set to : $dir_name" --button1 "OK"`

	exit
	
  endif # end device dropped

else # Prompt for new one

  set date = `date +%Y-%m-`
  set prompt_string = "New folder to recieve files : "
  set default_dir = "$dir_root"
  if ("$date_flag" != "") set default_dir = "$default_dir/$date"
  set ret = `"$ccd" inputbox --title "$prog" --informative-text "$prompt_string" --button1 "Create and copy" --button2 "Cancel" --button3 "Help" --float --text "$default_dir"`

  set retcode = `echo $ret | cut -c1`
  if ("$retcode" == "2") exit
  if ("$retcode" == "3") then
    set ret = `"$ccd" msgbox --title "$prog" --float --text "Help" --informative-text "CardUpload copies files from a removable device to a folder, for example images from a digital camera. You must first set the default device source folder by dropping that folder on to the application. After that, dropping a folder on the application will cause files to be copied from that device folder to the dropped folder. Starting the application with no folder will prompt to create a new folder." --button1 "OK"`
    exit
  endif

  set dir_name = `echo $ret | cut -c2-`
  if (! -d "$dir_name") mkdir "$dir_name"

endif # end prompt for folder

if (-d "$card_name" && -d "$dir_name") then

	# Convert unix path of dst to AS path
	set dir_string = ""
	set remains = `echo "$dir_name" | sed -e s/'\/$'//`
	loop1:
	 set dir = `echo "$remains" | sed -e s/'.*\/'//`
	 set remains = `echo "$remains" | sed -e s/'\/[^/]*$'//`
	 	set dir_string = "$dir_string folder "\""$dir"\"" of"
	if ("$remains" != "") goto loop1
	set dir_string = "$dir_string startup disk"

	# Convert unix of src path to AS path
	set card_string = ""
	set remains = `echo "$card_name" | sed -e s/'\/$'// -e s/'\/Volumes'//`
	loop2:
	 set dir = `echo "$remains" | sed -e s/'.*\/'//`
	 set remains = `echo "$remains" | sed -e s/'\/[^/]*$'//`
    if ("$remains" != "") then
	 	set card_string = "$card_string folder "\""$dir"\"" of"
		goto loop2
	else
   		set card_string = "$card_string disk "\""$dir"\"
		set device_name = "$dir"
	endif

# And start the copy		
osascript << EOF
    tell application "Finder"
	  duplicate every file of $card_string to $dir_string
	    --Old code for opening windows on src and dst
	    --make new Finder window to $card_string 
	    --make new Finder window to $dir_string
		eject "$dir"
	end tell
EOF

  ##set ret = `"$ccd" msgbox --title "$prog" --float --text "Success" --informative-text "$file_count files copied from $card_name to $dir_name" --button1 "OK"`

else # Dirs not found

  if (! -d $card_name) then
  	set ret = `"$ccd" msgbox --title "$prog" --float --text "Failed" --informative-text "Cannot find folder $card_name" --button1 "OK"`
   else 
  	set ret = `"$ccd" msgbox --title "$prog" --float --text "Failed" --informative-text "Cannot find folder $dir_name" --button1 "OK"`
  endif

endif

exit
